"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RabbitMQProvider = void 0;
const tslib_1 = require("tslib");
const callback_api_1 = tslib_1.__importDefault(require("amqplib/callback_api"));
class RabbitMQProvider {
    constructor() {
    }
    static create(url) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const provider = new RabbitMQProvider();
            yield provider.connect(url);
            return provider;
        });
    }
    connect(url) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            this.connection = yield new Promise((resolve, reject) => {
                callback_api_1.default.connect(url, (err, conn) => {
                    if (err)
                        reject(err);
                    else
                        resolve(conn);
                });
            });
            this.channel = yield new Promise((resolve, reject) => {
                this.connection.createChannel((err, channel) => {
                    if (err)
                        reject(err);
                    else
                        resolve(channel);
                });
            });
        });
    }
    publish(queue, message) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this.channel.assertQueue(queue);
            this.channel.sendToQueue(queue, Buffer.from(JSON.stringify(message)));
        });
    }
    consume(queue, callback) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield this.channel.assertQueue(queue);
            this.channel.consume(queue, (msg) => {
                if (msg) {
                    callback(JSON.parse(msg.content.toString()));
                    this.channel.ack(msg);
                }
            });
        });
    }
}
exports.RabbitMQProvider = RabbitMQProvider;
//# sourceMappingURL=rabbitmq.provider.js.map